@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
 our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -435,6 +435,42 @@ sub format_bencher_result {
      {'cmdline.skip_format'=>1}];
 }
 
+$SPEC{chart_bencher_result} = {
+    v => 1.1,
+    summary => 'Generate chart of bencher result and display it',
+    args => {
+        json => {
+            summary => 'JSON data',
+            schema => 'str*', # XXX filename
+            req => 1,
+            pos => 0,
+            cmdline_src => 'stdin_or_file',
+        },
+    },
+};
+sub chart_bencher_result {
+    require Bencher::Backend;
+    require Browser::Open;
+    require File::Temp;
+
+    my %args = @_;
+
+    my $envres = _json->decode($args{json});
+
+    my ($temp_fh, $temp_fname) = File::Temp::tempfile();
+
+    $temp_fname .= ".png";
+
+    my $chart_res = Bencher::Backend::chart_result(
+        envres => $envres, output_file => $temp_fname, overwrite=>1);
+
+    return $chart_res if $chart_res->[0] != 200;
+
+    my $view_res = Browser::Open::open_browser("file:$temp_fname");
+
+    $view_res ? [500, "Failed"] : [200, "OK"];
+}
+
 1;
 # ABSTRACT: Utilities related to bencher
 
@@ -450,7 +486,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.16 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-07-13.
+This document describes version 0.17 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
@@ -460,6 +496,8 @@ This distribution includes several utilities:
 
 =over
 
+=item * L<chart-bencher-result>
+
 =item * L<cleanup-old-bencher-results>
 
 =item * L<format-bencher-result>
@@ -473,6 +511,34 @@ This distribution includes several utilities:
 =head1 FUNCTIONS
 
 
+=head2 chart_bencher_result(%args) -> [status, msg, result, meta]
+
+Generate chart of bencher result and display it.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<json>* => I<str>
+
+JSON data.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 cleanup_old_bencher_results(%args) -> [status, msg, result, meta]
 
 Delete old results.
